@@ -25,6 +25,8 @@ LsDateTime::LsDateTime(QString name):
     connect(&m_Timer, SIGNAL(timeout()), this, SLOT(timerSlot()));
     m_Timer.setInterval(500);
     m_Timer.setSingleShot(false);    
+
+    m_StandbyTimer = NULL;
 }
 
 void LsDateTime::applySettings()
@@ -40,8 +42,15 @@ void LsDateTime::applySettings()
     if (m_TimeFormat.contains("s"))
         m_Timer.setInterval(500);
     else
-        m_Timer.setInterval(2000);
+        m_Timer.setInterval(1000);
 
+    int backgroundUpdate = getSetting("BackgroundUpdateIntervalSeconds", 0).toInt();
+    if (backgroundUpdate > 0){
+        m_StandbyTimer = new QTimer(this);
+        connect(m_StandbyTimer, SIGNAL(timeout()), this, SLOT(timerSlot()));
+        m_StandbyTimer->setInterval(backgroundUpdate * 1000);
+        m_StandbyTimer->setSingleShot(false);
+    }
     m_TimeFont = getFontSetting("TimeFont", QFont("", 30, QFont::Normal, false));
 
     QFontMetrics fm(m_TimeFont);
@@ -91,10 +100,14 @@ void LsDateTime::timerSlot()
 void LsDateTime::stopUpdate()
 {
     m_Timer.stop();
+    if (m_StandbyTimer)
+        m_StandbyTimer->start();
 }
 
 void LsDateTime::startUpdate()
 {
+    if (m_StandbyTimer)
+        m_StandbyTimer->stop();
     if (!m_Timer.isActive()){
         timerSlot();
         m_Timer.start();
