@@ -7,9 +7,10 @@ LsMovableImage::LsMovableImage(QString name) :
     setFlag(QGraphicsItem::ItemIsMovable, true);
 }
 
-void LsMovableImage::paint(QPainter *painter, const QStyleOptionGraphicsItem*,
+void LsMovableImage::paint(QPainter *painter, const QStyleOptionGraphicsItem* option,
            QWidget*)
 {
+    painter->setClipRect(option->exposedRect);
     if (m_IsPressed && !m_PressedImage.isNull())
         painter->drawPixmap(0,0,m_PressedImage);
     else if (!m_Image.isNull())
@@ -64,6 +65,11 @@ void LsMovableImage::mousePressEvent(QGraphicsSceneMouseEvent *event)
     update();
 }
 
+void LsMovableImage::doMouseRelease()
+{
+    mouseReleaseEvent(new QGraphicsSceneMouseEvent());
+}
+
 void LsMovableImage::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
     qDebug() << "mouseReleaseEvent:" << name() << mapToScene(event->pos());
