@@ -99,6 +99,17 @@ void LsNotification::paint(QPainter *painter, const QStyleOptionGraphicsItem* op
             painter->drawText(rect, Qt::AlignLeft | Qt::AlignVCenter | Qt::TextSingleLine, m_Text);
         }
         break;
+    case Qt::AlignCenter:
+        {
+            if (!m_Icon.isNull()){
+                painter->drawPixmap(size().width() / 2 - m_Icon.width() / 2, size().height() / 2 - m_Icon.height() / 2, m_Icon);
+            }
+
+            painter->setFont(m_Font);
+            painter->setPen(m_Color);
+            painter->drawText(rect, Qt::AlignCenter | Qt::TextSingleLine, m_Text);
+        }
+        break;
     default:
         break;
     }
@@ -138,6 +149,8 @@ void LsNotification::applySettings()
         m_Alignment = Qt::AlignLeft;
     else if (textPos == "right")
         m_Alignment = Qt::AlignRight;
+    else if (textPos == "center")
+        m_Alignment = Qt::AlignCenter;
 
     //m_Alignment = getAlignmentSetting("TextAlignment", Qt::AlignHCenter, Qt::AlignBottom);
     m_Color = getColorSetting("Color", QColor(255,255,255));
